==> mingw-w64-starpu-1.4.7-1.src.tar.zst: starpu-1.4.7/doc/doxygen_web_applications/html_web_applications/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Applications", "index.html", [
    [ "A Vector Scaling Application", "VectorApplication.html", [
      [ "Base version", "VectorApplication.html#BaseVersion", null ],
      [ "StarPU C version", "VectorApplication.html#StarPUCversion", [
        [ "Computation Kernels", "VectorApplication.html#ComputationKernels", null ],
        [ "Main Code", "VectorApplication.html#MainCode", null ]
      ] ],
      [ "Building and Running", "VectorApplication.html#BuildingandRunning", null ]
    ] ],
    [ "A Stencil Application", "StencilApplication.html", [
      [ "The Original Application", "StencilApplication.html#StencilOriginal", null ],
      [ "The StarPU Application", "StencilApplication.html#StencilStarPU", null ],
      [ "The StarPU MPI Application", "StencilApplication.html#StencilStarPUMPI", null ],
      [ "Running the application", "StencilApplication.html#StencilRunning", null ]
    ] ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Files.html",
"group__API__Codelet__And__Tasks.html#ga18bec8430309a613520d6042d701790d",
"group__API__Data__Interfaces.html#ga0022c371e342ac366720c7735f4be3be",
"group__API__Data__Management.html#ga5fd09305716ce9d3a5a9fd2df6bc7792",
"group__API__Initialization__and__Termination.html#a2f4b44f119a585f08418771ce62321a1",
"group__API__MPI__Support.html#ga533a908fa669cd81cfbe0323771985ad",
"group__API__OpenCL__Extensions.html#ga9a1331f26cc54a1f5406770f68b95d29",
"group__API__Perf__Monitoring.html#gad3e6ba0b643d9bd1a3e8920bf0b3dbea",
"group__API__SC__Hypervisor.html#a9aba37893ddb344de680aa901f686f2d",
"group__API__Standard__Memory__Library.html#ga49603eaea3b05e8ced9ba1bd873070c3",
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37da6afc9f886af7206833d473e20d2343e7",
"interfacefstarpu__mod_1_1fstarpu__df__alloc__bcsr__filter__canonical__block.html",
"interfacefstarpu__mod_1_1fstarpu__task__finished.html",
"sc__hypervisor__monitoring_8h.html#adfbc9bbc2fb020e1b0c847f8557e45d6"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> mingw-w64-starpu-1.4.9-1.src.tar.zst: starpu-1.4.9/doc/doxygen_web_applications/html_web_applications/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Applications", "index.html", [
    [ "A Vector Scaling Application", "VectorApplication.html", [
      [ "Base version", "VectorApplication.html#BaseVersion", null ],
      [ "StarPU C version", "VectorApplication.html#StarPUCversion", [
        [ "Computation Kernels", "VectorApplication.html#ComputationKernels", null ],
        [ "Main Code", "VectorApplication.html#MainCode", null ]
      ] ],
      [ "Building and Running", "VectorApplication.html#BuildingandRunning", null ]
    ] ],
    [ "A Stencil Application", "StencilApplication.html", [
      [ "The Original Application", "StencilApplication.html#StencilOriginal", null ],
      [ "The StarPU Application", "StencilApplication.html#StencilStarPU", null ],
      [ "The StarPU MPI Application", "StencilApplication.html#StencilStarPUMPI", null ],
      [ "Running the application", "StencilApplication.html#StencilRunning", null ]
    ] ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Files.html",
"group__API__Codelet__And__Tasks.html#ga104354f28f90926008105218bbdf974e",
"group__API__Data__Interfaces.html#afd365e7e0abc01f07b6d7b9201c4ce22",
"group__API__Data__Management.html#ga586146498466b60d6b81145dfaeb8948",
"group__API__Initialization__and__Termination.html#a2275c89ee0aded13cc8836a0c5ef0188",
"group__API__MPI__Support.html#ga4799c69cb64cee04cfff4917f7cdf151",
"group__API__OpenCL__Extensions.html#ga84a524eaac758722f083ee129a19a567",
"group__API__Perf__Monitoring.html#gab6b19fe5667ce4ea447d19d5ed88ae7d",
"group__API__SC__Hypervisor.html#a79c6a87b792c849cc6c388dbf17d2d49",
"group__API__Standard__Memory__Library.html#ga1456598a362e4ee275247bd1a1d4327b",
"group__API__Workers.html#gaf48e8da13c523a7a9f2530349ddda29e",
"interfacefstarpu__mod_1_1fstarpu__data__unregister__no__coherency.html",
"interfacefstarpu__mod_1_1fstarpu__task__dup.html",
"sc__hypervisor__monitoring_8h.html#aba3d21edf846f13f3d41405ab7d99016"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
